@@ -1,4 +1,3 @@
-# encoding: utf-8
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 #
@@ -15,9 +14,9 @@ from ..importstring import import_item
 class TestImportItem(TestCase):
 
     def test_import_unicode(self):
-        self.assertIs(os, import_item(u'os'))
-        self.assertIs(os.path, import_item(u'os.path'))
-        self.assertIs(os.path.join, import_item(u'os.path.join'))
+        self.assertIs(os, import_item('os'))
+        self.assertIs(os.path, import_item('os.path'))
+        self.assertIs(os.path.join, import_item('os.path.join'))
 
     def test_bad_input(self):
         class NotAString(object):
@@ -26,5 +25,5 @@ class TestImportItem(TestCase):
             "import_item accepts strings, "
             "not '%s'." % NotAString
         )
-        with self.assertRaisesRegexp(TypeError, msg):
+        with self.assertRaisesRegex(TypeError, msg):
             import_item(NotAString())
